/*
	Description: Processes the NBER-CES manufacturing dataset and computes industry-level outcomes of interest.

	Author: Brendan Price
	Updated: July 29, 2014
*/

version 12.1
set more off
clear all

*** Program to rescale NBER-CES variables to actual quantities
capture program drop rescale
program define rescale
	replace emp = emp * 1000
	replace prode = prode * 1000

	foreach v in "pay" "prodw" "vship" "matcost" "vadd" "invest" "energy" "cap" {
		replace `v' = `v' * 1000000
	}
end

*** Program to deflate all variables ***
capture program drop deflate_variables
program define deflate_variables
	* Deflate shipments
	gen real_vship = vship/piship

	* Deflate materials costs
	gen real_matcost = matcost/pimat

	* Deflate investments
	gen real_invest = invest/piinv

	* Deflate energy expenditures
	gen real_energy = energy/pien

	* Drop price deflators (will recompute later)
	drop piship pimat piinv pien

	* Rename variables for clarity
	rename prode prodemp
	rename prodw prodpay

	* Deflate total payroll and production payroll using the PCE (to 2007 dollars)
	merge m:1 year using "../../../dta/pce/pce.dta", assert(2 3)
	keep if _merge == 3
	drop _merge
	
	gen real_pay = pay/pce
	gen real_prodpay = prodpay/pce
	drop pce

	* Retain nominal variables, but prepend "nom" to signify this
	rename vship nom_vship
	rename vadd nom_vadd
	rename matcost nom_matcost
	rename invest nom_invest
	rename energy nom_energy
	rename pay nom_pay
	rename prodpay nom_prodpay
	rename cap nom_cap
end

*** Program to collapse all quantities to a new level of industry aggregation
capture program drop recollapse
program define recollapse
	* Specify industry level we want to arrive at
	local indvar = "`1'"

	collapse (sum) emp prodemp nom_pay nom_prodpay nom_vship nom_vadd nom_matcost nom_invest nom_energy nom_cap real_pay real_prodpay real_vship real_matcost real_invest real_energy, by(year `indvar')
end

*** Program to back out the price indices from known real and nominal values
capture program drop compute_price_indices
program define compute_price_indices
	gen piship = nom_vship/real_vship
	gen pimat = nom_matcost/real_matcost
	gen piinv = nom_invest/real_invest
	gen pien = nom_energy/real_energy
end

*** Program to verify that variables have positive, non-missing values (except for industries that disappear after 1996)
capture program drop verify_values
program define verify_values
	foreach v of varlist emp prodemp nom_* real_* pi* {
		assert `v' > 0 & `v' < . if year <= 1996
		assert `v' > 0 & `v' < . if (year >= 1997) & !(sic87dd == 2411 | sic87dd == 2711 | sic87dd == 2721 | sic87dd == 2731 | sic87dd == 2741 | sic87dd == 2771 | sic87dd == 3299 | sic87dd == 3732)
	}
end

******* START OF MAIN CODE BODY *******

/* Convert 1997-2009 data from NAICS to SIC codes */

* Load NBER data in NAICS format and restrict to variables of interest
use "../../../dta/nberces/src/naics5809.dta", clear
keep naics year vship vadd matcost invest energy cap emp pay prode prodw piship pimat piinv pien

* Express quantities in actual units
rescale

* Use 1997-2009 data from the NAICS version of the dataset; panel should be balanced in these years
keep if year >= 1997 & year <= 2009
fillin naics year
assert _fillin == 0
drop _fillin

* Renormalize deflators to equal unity in 2007, instead of 1997
foreach pindex in "piship" "pimat" "piinv" "pien" {
	assert `pindex' > 0 & `pindex' < .
	bysort naics: egen `pindex'_2007 = total(`pindex' * (year == 2007))
	replace `pindex' = `pindex'/`pindex'_2007
	drop `pindex'_2007
	assert `pindex' == 1 if year == 2007
}

* Deflate shipments, inputs, and pay
deflate_variables

* Map into 1987 SIC codes
joinby naics using "../../../xwalks/ind/naics97_sic87/naics97_sic87.dta", unmatched(both) _merge(naics_merge)

* All NAICS industry codes should be accounted for
assert naics_merge == 2 | naics_merge == 3
keep if naics_merge == 3
drop naics_merge modified

* Weights should sum to unity within each industry, up to floating point error
bysort naics year: egen tot_weight = total(weight)
assert abs(1 - tot_weight) < .001
drop naics tot_weight

* Reweight in preparation for collapsing to the SIC87 level (NB: easy to omit a variable here, so I verify below)
foreach v of varlist emp prodemp nom_pay nom_prodpay nom_vship nom_vadd nom_matcost nom_invest nom_energy nom_cap real_pay real_prodpay real_vship real_matcost real_invest real_energy {
	replace `v' = `v' * weight
	local reweighted_`v' "yes"	
}
drop weight

* Verify that all quantitative variables were properly reweighted
quietly describe, varlist
local full_varlist = r(varlist)

foreach v of local full_varlist {
	* These variables are exceptions: all others should have been reweighted
	if "`v'" != "sic" & "`v'" != "year" {
		assert "`reweighted_`v''" == "yes"
		macro drop reweighted_`v'
	}
}

* Drop instances in which industries are partly/fully mapped into non-manufacturing SIC codes
keep if sic >= 2000 & sic <= 3999

* Recollapse to the SIC87 level
recollapse sic

* Verify that this procedure results in a balanced panel of industries
quietly fillin sic year
assert _fillin == 0
drop _fillin

* Save temporary dataset and move on to the native SIC data
tempfile n1
save "`n1'.dta", replace

/* Working with native SIC data: for years 1963-1996 (NB: for some industries no data are available post-1996) */

* Load NBER-CES data in SIC format and restrict to variables of interest
use "../../../dta/nberces/src/sic5809.dta", clear
keep sic year vship vadd matcost invest energy cap emp pay prode prodw piship pimat piinv pien 

* Express quantities in actual units
rescale

* Impute price deflators as needed, and then renormalize (NB: these industries are excluded from analyses involving output)
foreach pindex in "piship" "pimat" "piinv" "pien" {
	* For industries that disappear after 1996, impute on the basis of the (recent) exponential trend
	gen log_`pindex' = log(`pindex')

	foreach ind in 2411 2711 2721 2731 2741 2771 3292 3732 {
		quietly reg log_`pindex' year if sic == `ind' & year >= 1987 & year <= 1996
		predict log_`pindex'_hat if sic == `ind' & `pindex' == .
		gen `pindex'_hat = exp(log_`pindex'_hat) if sic == `ind' & `pindex' == .
		replace `pindex' = `pindex'_hat if sic == `ind' & `pindex' == .
		drop log_`pindex'_hat `pindex'_hat
	}

	drop log_`pindex'
	
	* Renormalize deflators to equal unity in 2007, instead of 1987
	assert `pindex' > 0 & `pindex' < .
	bysort sic: egen `pindex'_2007 = total(`pindex' * (year == 2007))
	replace `pindex' = `pindex'/`pindex'_2007
	drop `pindex'_2007
}

* Use the data from 1963 through 1996 for this part
keep if year >= 1963 & year <= 1996

* Verify that we have a balanced panel of industries
quietly fillin sic year
assert _fillin == 0
drop _fillin

* Deflate shipments, inputs, and pay
deflate_variables

/*
	Combine data from the SIC years with data from the NAICS years.
	Save a cleaned dataset at the 4-digit level.
*/

* Append the data from the NAICS years
append using "`n1'.dta"

* Verify that no "auxiliary industry" codes (20001, 30001, etc.) are present
assert sic <= 9999

* Map into sic87dd codes
rename sic sic87
do "../../../xwalks/ind/sic87_sic87dd/sic87_sic87dd.do"

* Verify that we only have manufacturing industries (after excluding the fishing industry)
drop if sic87dd == 0900
assert sic87dd >= 2000 & sic87dd <= 3999

* Note the industries that are partly/wholly reclassified into non-manufacturing under NAICS
gen reclassified = (sic87 == 2411 | sic87 == 2711 | sic87 == 2721 | sic87 == 2731 | sic87 == 2741 | sic87 == 2771 | sic87 == 3292 | sic87 == 3732)
assert (sic87dd == 2411 | sic87dd == 2711 | sic87dd == 2721 | sic87dd == 2731 | sic87dd == 2741 | sic87dd == 2771 | sic87dd == 3299 | sic87dd == 3732) if reclassified == 1

* Recollapse to the sic87dd level
recollapse sic87dd

* Fill in missing industry-year combinations
quietly fillin sic87dd year
assert sic87dd == 2411 | sic87dd == 2711 | sic87dd == 2721 | sic87dd == 2741 if _fillin == 1
drop _fillin

* Back out price indices from real/nominal variables
compute_price_indices

* Delete any post-1996 data for industries that are partly/wholly reclassified out of manufacturing under NAICS
#delimit ;
gen any_reclassified =
	sic87dd == 2411 |
	sic87dd == 2711 |
	sic87dd == 2721 |
	sic87dd == 2731 |
	sic87dd == 2741 |
	sic87dd == 2771 |
	sic87dd == 3299 |
	sic87dd == 3732;
#delimit cr

foreach v of varlist emp prodemp nom_* real_* pi* {
	* Delete post-1996 data for reclassified industries
	replace `v' = . if (year > 1996) & (any_reclassified == 1)

	* All remaining data points should be strictly positive and non-missing
	assert `v' > 0 & `v' < . if (year <= 1996)
	assert `v' > 0 & `v' < . if (year > 1996) & (any_reclassified == 0)
}

* Save a cleaned version of the NBER-CES data
drop any_reclassified
save "../../../dta/nberces/clean/nberces_clean.dta", replace



