/*
	Description: Clean data on county-level population and demographic structure
	
	Author: Brendan Price
	Updated: July 30, 2014
	
	Note: Because of their considerable size, the underlying source data are NOT provided in this replication package. The file dta/popest/popest-readme.txt reports where these underlying data may be downloaded.
*/

version 12.1
set more off
clear all

local popdir "../../../dta/popest"

/* Process data from 1990-1999 */

forvalues year = 1990/1999 {
	local yy = substr("`year'", 3, 2)

	* Load raw intercensal population estimates
	infile year cty_fips agegrp race_sex ethnicity pop using "`popdir'/src/intercensal-1990-1999/STCH-icen`year'.txt", clear

	* Confirm data structure
	quietly fillin cty_fips year agegrp race_sex ethnicity
	assert _fillin == 0
	drop _fillin

	* Clean up the year indicator
	assert year == `yy'
	replace year = `year'

	* Pool all sexes/races/ethnicities
	collapse (sum) pop, by(cty_fips year agegrp)
	bysort cty_fips year: egen totpop = total(pop)
	
	* Reshape to one observation per county x year
	reshape wide pop, i(cty_fips year) j(agegrp)
	
	* Compute working-age population (ages 15-64)
	gen workagepop = pop4 + pop5 + pop6 + pop7 + pop8 + pop9 + pop10 + pop11 + pop12 + pop13
	keep cty_fips year totpop workagepop
	order cty_fips year totpop workagepop
	
	* Combine files across years
	if `year' == 1990 {
		tempfile pop_1990_1999
		save "`pop_1990_1999'.dta", replace
	}
	else {
		tempfile pop`year'
		save "`pop`year''.dta", replace
		use "`pop_1990_1999'.dta", clear
		append using "`pop`year''.dta"
		save "`pop_1990_1999'.dta", replace
	}
}

/* Process data from 2000-2009 */

* File to be constructed by appending state files
tempfile pop_2000_2009

local flist : dir "`popdir'/src/intercensal-2000-2010" files "*.csv" 

* Loop through files from individual states
foreach f of local flist {
	* Restrict to variables we need
	insheet using "`popdir'/src/intercensal-2000-2010/`f'", comma clear names
	keep state county year agegrp tot_pop

	* State code should coincide with file name
	local st = substr("`f'", -6, 2)
	assert state == `st'

	* Construct county FIPS codes
	gen cty_fips = (1000 * state) + county
	drop state county

	* Confirm data structure
	quietly fillin cty_fips year agegrp
	assert _fillin == 0
	drop _fillin

	* Use estimates from July of each year (and drop 2010)
	keep if (year >= 2 & year <= 11)
	replace year = year + 1998
	
	* Drop county x year combinations for which population is missing (due e.g. to creation of new counties)
	local ptype : type tot_pop
	if regexm("`ptype'", "str") == 1 {
		drop if tot_pop == "X"
		destring tot_pop replace
	}
	
	* Retain total by age group
	rename tot_pop totpop
	reshape wide totpop, i(cty_fips year) j(agegrp)
	
	* Retain total and working-age population (age 15-64)
	gen totpop = totpop99
	gen workagepop = totpop4 + totpop5 + totpop6 + totpop7 + totpop8 + totpop9 + totpop10 + totpop11 + totpop12 + totpop13

	keep cty_fips year totpop workagepop
	order cty_fips year totpop workagepop
	
	if `st' == 01 {
		save "`pop_2000_2009'.dta", replace
	}
	else {
		tempfile pop`st'
		save "`pop`st''.dta", replace
		use "`pop_2000_2009'.dta", clear
		append using "`pop`st''.dta"
		save "`pop_2000_2009'.dta", replace
	}
}

/* Process data from 2010-2012 */

* Restrict to variables we need
insheet using "`popdir'/src/vintage2012-2010-2012/CC-EST2012-ALLDATA.csv", comma clear
keep state county year agegrp tot_pop

* Construct county FIPS codes
gen cty_fips = (1000 * state) + county
drop state county

* Confirm data structure
quietly fillin cty_fips year agegrp
assert _fillin == 0
drop _fillin

* Use estimates from July of each year
keep if year >= 3 & year <= 5
replace year = year + 2007

* Retain total population by age group
rename tot_pop totpop
reshape wide totpop, i(cty_fips year) j(agegrp)

* Retain total and working-age populations
gen totpop = totpop0
gen workagepop = totpop4 + totpop5 + totpop6 + totpop7 + totpop8 + totpop9 + totpop10 + totpop11 + totpop12 + totpop13

keep cty_fips year totpop workagepop
order cty_fips year totpop workagepop

* Save population estimates from 2010 to 2012
tempfile pop_2010_2012
save "`pop_2010_2012'.dta", replace

/* Combine population estimates for 1990 to 2012 */

use "`pop_1990_1999'.dta", clear
append using "`pop_2000_2009'.dta"
append using "`pop_2010_2012'.dta"

save "`popdir'/clean/cty_pop_1990_2012.dta", replace

* Map to commuting zones (dropping Alaska and Hawaii)
use "`popdir'/clean/cty_pop_1990_2012.dta", clear
drop if floor(cty_fips/1000) == 2 | floor(cty_fips/1000) == 15
merge m:1 cty_fips using "../../../xwalks/geo/cw_cty_czone_mod.dta", assert(2 3)
keep if _merge == 3
drop _merge
collapse (sum) totpop workagepop, by(czone year)
distinct czone
assert r(ndistinct) == 722
compress
save "`popdir'/clean/czone_pop_1990_2012.dta", replace
rm "`popdir'/clean/cty_pop_1990_2012.dta"

