/*
	Description: Classifies industries on the basis of import exposure and tradability
	
	Author: Brendan Price
	Updated: February 2, 2015
	
	Note: The script "master_builder.do" (in the folder do/build/national) must be executed before this program is run.
*/

version 12.1
set more off

local cleandir "../../../dta/cbp/county/clean"

/* Classify manufacturing industries into exposed and nonexposed tradables */

use "../../../dta/sample/main.dta", clear
keep sic87dd manuf cbp_emp1991 d_import_usch_1991_2011 d_import_otch_1991_2011 d_up_LT_usch_1991_2011 d_up_LT_otch_1991_2011

* Undo annualizations
foreach v in d_import_usch_1991_2011 d_import_otch_1991_2011 d_up_LT_usch_1991_2011 d_up_LT_otch_1991_2011 {
	replace `v' = `v' * (2011 - 1991)
}

* Predict "exogenous" changes in direct exposure
reg d_import_usch_1991_2011 d_import_otch_1991_2011 if manuf == 1 [aw = cbp_emp1991]
gen predicted_direct_exposure = (d_import_otch_1991_2011 * _b[d_import_otch_1991_2011]) if manuf == 1

* Define an industry as directly exposed if the predicted change exceeds 2% of baseline US market volume
gen exposed_directly  = (predicted_direct_exposure >= 2) if manuf == 1
replace exposed_directly = 0 if manuf == 0

* Predict "exogenous" change in "full" (Leontief) upstream exposure
reg d_up_LT_usch_1991_2011 d_up_LT_otch_1991_2011 [aw=cbp_emp1991]
gen predicted_upstream_exposure = (d_up_LT_otch_1991_2011 * _b[d_up_LT_otch_1991_2011])

* Define an industry as exposed upstream if the predicted change exceeds 4% of baseline US market volume
gen exposed_upstream = (predicted_upstream_exposure >= 4)

tab exposed_directly exposed_upstream
tab exposed_directly exposed_upstream if manuf == 1
tab exposed_directly exposed_upstream if manuf == 0

keep sic87dd exposed_directly exposed_upstream
tempfile exposure
save "`exposure'.dta", replace

/*
	Classify industries as tradable and non-tradable.
	Note that the distinction here lumps everything that is not "clearly tradable" into "non-tradable."
*/

use "../../../xwalks/ind/sic87_sic87dd/sic87dd_key.dta", clear

* Tradables: agriculture/forestry/fishing, mining, and manufacturing
gen tradable = 0
replace tradable = 1 if sic87dd == 0710 | sic87dd == 0800 | sic87dd == 0900
replace tradable = 1 if sic87dd >= 1010 & sic87dd <= 1474
replace tradable = 1 if sic87dd >= 2000 & sic87dd <= 3999

* Merge in industry exposure
merge 1:1 sic87dd using "`exposure'.dta", assert(1 3) nogenerate
assert exposed_directly == 0 | exposed_directly == 1
assert exposed_upstream == 0 | exposed_upstream == 1
assert tradable == 0 | tradable == 1
order sic87dd_desc sic87dd exposed_directly exposed_upstream tradable

* Save a list	
save "`cleandir'/classification/industry_classification.dta", replace


