/*
	Description: Creates Appendix Table 4 (computing summary statistics for the regional analysis)

	Author: Brendan Price
	Updated: July 31, 2014
*/

version 12.1
set more off
clear all
set matsize 11000

* Directory paths
local cleandir "../../dta/cbp/county/clean"
local outdir "../../out"

* Compute employment in each CZ in each exposure/tradability sector
use "`cleandir'/emp_counts/cbp_czone_merged.dta", clear
keep if year == 1991 | year == 1999 | year == 2011
merge m:1 sic87dd using "`cleandir'/classification/industry_classification.dta", assert(3) nogenerate

gen class = .
replace class = 1 if exposed_directly == 1 | exposed_upstream == 1
replace class = 2 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 1
replace class = 3 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 0
assert class != .

collapse (sum) emp, by(czone class year)
fillin czone class year
assert _fillin == 0
drop _fillin

reshape wide emp, i(czone year) j(class)

* Compute total employment by summing across classes
gen emp0 = emp1 + emp2 + emp3

forvalues i = 0/3 {
	rename emp`i' emp`i'_
}

reshape wide emp0_ emp1_ emp2_ emp3_, i(czone) j(year)

tempfile empcounts
save "`empcounts'.dta", replace

* Merge in CZ population from the Census Population Estimates
use "../../dta/popest/clean/czone_pop_1990_2012.dta", clear
keep if year == 1991 | year == 1999 | year == 2011
rename totpop pop
reshape wide pop workagepop, i(czone) j(year)
order czone pop* workagepop*
tempfile popest
save "`popest'.dta", replace

use "`empcounts'.dta", clear
merge 1:1 czone  using "`popest'.dta", assert(3) nogenerate

* Merge in and annualize CZ import shocks
merge 1:1 czone using "`cleandir'/shocks/czone_import_shocks.dta", assert(3) nogenerate keepusing(*1991_1999 *1999_2011) 

foreach g in "us" "ot" {
	foreach t in "1991_1999" "1999_2011" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		gen shock_`g'_`t' = d_czone_imp_exp_`g'ch_`t'/(`end' - `start')
	}
}

* Compute (annualized) changes in employment/population
forvalues i = 0/3 {
	foreach y in 1991 1999 2011 {
		gen emppop`i'_`y' = 100 * (emp`i'_`y'/workagepop`y')
	}

	foreach t in "1991_1999" "1999_2011" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		gen d_emppop`i'_`t' = (emppop`i'_`end' - emppop`i'_`start')/(`end' - `start')
	}
}

foreach v in "shock_us" "shock_ot" "d_emppop0" "d_emppop1" "d_emppop2" "d_emppop3" {
	foreach t in "1991_1999" "1999_2011" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		* Compute summary statistics, weighting by industry size at start of period
		quietly sum `v'_`t' [aw=pop1991], detail
	
		local n_`t' = r(N)
		local mean_`t' = r(mean)
		local sd_`t' = r(sd)
		local median_`t' = r(p50)
		local min_`t' = r(min)
		local max_`t' = r(max)
	}

	* Row of means, medians, mins, maxes
	mat row1 = (`n_1991_1999', `mean_1991_1999', `median_1991_1999', `min_1991_1999', `max_1991_1999', `mean_1999_2011', `median_1999_2011', `min_1999_2011', `max_1999_2011')
	mat rownames row1 = "`v'"

	* Row of standard deviations
	mat row2 = (., `sd_1991_1999', ., ., ., `sd_1999_2011', ., ., .)
	mat rownames row2 = "`v'"
	
	* Tack on to stats matrix
	capture confirm mat stats
	if _rc != 0 {
		mat stats = row1
	}
	else {
		mat stats = (stats \ row1)
	}
	mat stats = (stats \ row2)
}

* Load a dataset of summary stats into memory
clear
svmat stats

* Add a column indicating variable names
local names: rownames stats
mat drop stats

gen v = ""
order v

forvalues i = 1/`=_N' {
	local name: word `i' of `names'
	replace v = "`name'" in `i'
}

* Update the "raw data" sheet in the Excel file
export excel "`outdir'/AADHP-JOLE-Appendix.xlsx", sheetreplace sheet(AppTab4_Raw)


