/*
	Description: Creates Figure 2 (graph showing changes in trade flows and import penetration)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all
capture restore, not
set scheme s1color

local outdir "../../out"

* Prepare PCE deflator
use "../../dta/pce/pce.dta", clear

forvalues i = 1991/2011 {
	quietly sum pce if year == `i'
	local pce`i' = r(mean)
}

* Load the estimation sample
use "../../dta/sample/main.dta", clear

keep sic87dd manuf real_imports_usch_* real_exports_usch_* real_market*

forvalues i = 1991/2011 {
	* Compute total level of US manufacturing imports from China
	egen tot_imports_usch`i' = total(real_imports_usch_`i')

	* Compute total level of US manufacturing exports to China
	if `i' >= 1992 {
		egen tot_exports_usch`i' = total(real_exports_usch_`i')
	}

	if `i' <= 2009 {	
		* Compute total US market volume
		egen tot_market`i' = total(real_market`i')

		* Compute Chinese import penetration
		gen usch_ipr`i' = 100 * (tot_imports_usch`i'/tot_market`i')
	}
}

keep tot_imports_usch* tot_exports_usch* usch_ipr*
duplicates drop
assert _N == 1

gen i = 1
reshape long tot_imports_usch tot_exports_usch usch_ipr, i(i) j(year)
drop i

* Express imports and exports in billions
replace tot_imports_usch = tot_imports_usch/1000000000
replace tot_exports_usch = tot_exports_usch/1000000000

* Label import penetration variable
label var usch_ipr "Chinese Import Penetration Ratio (%)"

* Trade plot
#delimit ;
twoway
	(connected tot_imports_usch tot_exports_usch year, yaxis(1) ytitle("Trade Flows (Billions of 2007 Dollars)", axis(1) suffix size(medsmall)) msymbol(circle diamond) clcolor(navy maroon) clpattern(solid longdash) mcolor(navy maroon) ylabel(0(50)400, angle(0) grid) ymtick(0(25)400))
	(connected usch_ipr year, yaxis(2) ytitle("Chinese Import Penetration Ratio (%)", axis(2)) msymbol(square) clcolor(dkorange) clpattern(shortdash) mcolor(dkorange) ylabel(0(1)6, angle(0) axis(2)) ymtick(0(.5)6, axis(2))),
	title("")
	xtitle("")
	xlabel(1991(4)2011)
	xmtick(1991(2)2011)	
	legend(size(medsmall) rows(3)
		label(1 "U.S. Imports from China")
		label(2 "U.S. Exports to China")
		label(3 "Chinese Import Penetration Ratio"));
#delimit cr

graph export "`outdir'/figs/Fig2.eps", replace
!epstopdf --outfile="`outdir'/figs/Fig2.pdf" "`outdir'/figs/Fig2.eps"


