/*
	Description: Creates Table 1 (summary statistics for trade and outcome variables)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Distinguish manufacturing and nonmanufacturing outcomes in the CBP
foreach t in "1991_2011" "1991_1999" "1999_2011" "1999_2007" "2007_2011" {
	gen dl_cbp_emp_manuf_`t' = dl_cbp_emp_`t' if manuf == 1
	gen dl_cbp_emp_nonmanuf_`t' = dl_cbp_emp_`t' if manuf == 0
}

foreach v in "d_import_usch" "d_import_otch" "dl_cbp_emp_manuf" "dl_cbp_emp_nonmanuf" {
	foreach t in "1991_2011" "1991_1999" "1999_2011" "1999_2007" "2007_2011" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		* Compute summary statistics, weighting by industry size at start of period
		quietly sum `v'_`t' [aw = cbp_emp1991], detail
	
		local n_`t' = r(N)
		local mean_`t' = r(mean)
		local sd_`t' = r(sd)
		local median_`t' = r(p50)
		local min_`t' = r(min)
		local max_`t' = r(max)
	}

	* Row of means, medians, mins, maxes
	mat row1 = (`n_1991_2011', `mean_1991_2011', `median_1991_2011', `min_1991_2011', `max_1991_2011', `mean_1991_1999', `mean_1999_2011', `mean_1999_2007', `mean_2007_2011')
	mat rownames row1 = "`v'"

	* Row of standard deviations
	mat row2 = (., `sd_1991_2011', ., ., ., `sd_1991_1999', `sd_1999_2011', `sd_1999_2007', `sd_2007_2011')
	mat rownames row2 = "`v'"
	
	* Tack on to stats matrix
	capture confirm mat stats
	if _rc != 0 {
		mat stats = row1
	}
	else {
		mat stats = (stats \ row1)
	}
	mat stats = (stats \ row2)
}

* Load a dataset of summary stats into memory
clear
svmat stats

* Add a column indicating variable names
local names: rownames stats
mat drop stats

gen v = ""
order v

forvalues i = 1/`=_N' {
	local name: word `i' of `names'
	replace v = "`name'" in `i'
}

* Update the "raw data" sheet in the Excel file
export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab1_Raw)


