/*
	Description: Creates Table 6 (incorporating upstream and downstream linkages)

	Author: Brendan Price
	Updated: February 2, 2015
*/

version 12.1
set more off
clear all
capture log close

local outdir "../../out"

* Partial R-squared factor used to "discount" implied employment changes
local pfactor = .56

* Predict implied employment change
capture program drop compute_changes
program define compute_changes
	* Compute predicted changes over the full period
	egen tot_pred_d_emp_mfg = total(pred_d_emp * manuf)
	egen tot_pred_d_emp_nonmfg = total(pred_d_emp * nonmanuf)
	egen tot_pred_d_emp = total(pred_d_emp)

	* Compute predicted changes separately by period
	forvalues i = 1/2 {
		egen t`i'_tot_pred_d_emp_mfg = total(pred_d_emp * manuf * t`i')
		egen t`i'_tot_pred_d_emp_nonmfg = total(pred_d_emp * nonmanuf * t`i')
		egen t`i'_tot_pred_d_emp = total(pred_d_emp * t`i')
	}

	foreach d in tot_pred_d_emp_mfg tot_pred_d_emp_nonmfg tot_pred_d_emp t1_tot_pred_d_emp_mfg t1_tot_pred_d_emp_nonmfg t1_tot_pred_d_emp t2_tot_pred_d_emp_mfg t2_tot_pred_d_emp_nonmfg t2_tot_pred_d_emp {
		quietly sum `d'
		estadd scalar `d' = r(mean)
	}

	drop tot_pred_d_emp_mfg tot_pred_d_emp_nonmfg tot_pred_d_emp t1_tot_pred_d_emp_mfg t1_tot_pred_d_emp_nonmfg t1_tot_pred_d_emp t2_tot_pred_d_emp_mfg t2_tot_pred_d_emp_nonmfg t2_tot_pred_d_emp
	replace pred_d_emp = 0
end

foreach k in "firstorder" "leontief" {
	* Load the estimation sample
	use "../../dta/sample/main.dta", clear

	* Specify sector controls
	local sector_controls "sector2 sector3 sector4 sector5 sector6 sector7 sector8 sector9 sector10"
			
	* Restrict to variables we need
	#delimit ;
	keep sic87dd manuf sic3 cbp_emp1991 cbp_emp1999 cbp_emp2007 cbp_emp2011 `sector_controls'
		dl_cbp_emp_1991_1999 dl_cbp_emp_1999_2011 dl_cbp_emp_1999_2007
		d_import_*_1991_1999 d_import_*_1999_2011 d_import_*_1999_2007
		d_up_*_1991_1999 d_up_*_1999_2011 d_up_*_1999_2007
		d_down_*_1991_1999 d_down_*_1999_2011 d_down_*_1999_2007;
	#delimit cr

	* Use either "first-order" or "Leontief" measures of import exposure as desired and use standardized variable names
	if "`k'" == "firstorder" {
		drop d_up_LT_* d_down_LT_*
	}
	else if "`k'" == "leontief" {
		drop d_up_usch_* d_up_otch_* d_down_usch_* d_down_otch_*
		
		foreach v of varlist d_*_LT_* {
			local new_v = regexr("`v'", "_LT_", "_")
			rename `v' `new_v'
		}
	}

	* Switch to stacked first differences
	reshape long dl_cbp_emp_ d_import_usch_ d_import_otch_ d_up_usch_ d_up_otch_ d_down_usch_ d_down_otch_, i(sic87dd) j(period) string

	foreach v in "dl_cbp_emp" "d_import_usch" "d_import_otch" "d_up_usch" "d_up_otch" "d_down_usch" "d_down_otch" {
		rename `v'_ `v'
	}

	* Set direct trade changes to zero for non-manufacturing industries
	replace d_import_usch = 0 if manuf == 0
	replace d_import_otch = 0 if manuf == 0

	* Construct "omnibus" exposure measures that combine direct and upstream import exposure
	gen d_omnibus_usch = d_import_usch + d_up_usch
	gen d_omnibus_otch = d_import_otch + d_up_otch

	* Time dummies
	gen t1 = (period == "1991_1999")
	gen t2 = (period == "1999_2011") | (period == "1999_2007")

	* Label regressors
	label var t1 "1{1991-1999}"
	label var t2 "1{1999-2011 or 1999-2007}"

	* Sector dummies
	gen nonmanuf = (manuf == 0)
	label var manuf "Manufacturing dummy"
	label var nonmanuf "Non-manufacturing dummy"

	* Time/sector interactions
	forvalues i = 1/2 {
		gen t`i'_manuf = t`i' * manuf
		gen t`i'_nonmanuf = t`i' * nonmanuf
	}

	label var t1_manuf "1{1991-1999} x Manufacturing"
	label var t2_manuf "1{1999-2011 or 1999-2007} x Manufacturing"
	label var t1_nonmanuf "1{1991-1999} x Non-Manufacturing"
	label var t2_nonmanuf "1{1999-2011 or 1999-2007} x Non-Manufacturing"

	* End-of-period employment for use in employment calculations
	gen L1 = cbp_emp1999 if period == "1991_1999"
	replace L1 = cbp_emp2011 if period == "1999_2011"
	replace L1 = cbp_emp2007 if period == "1999_2007"

	* Factors needed to rescale coefficients (to undo multiplication by 100 and also annualization)
	gen lambda = 100 / (1999 - 1991) if period == "1991_1999"
	replace lambda = 100 / (2011 - 1999) if period == "1999_2011"
	replace lambda = 100 / (2007 - 1999) if period == "1999_2007"
	assert lambda != .

	* Variable to store computed employment losses
	gen pred_d_emp = 0

	* Merge in industry names
	merge m:1 sic87dd using "../../xwalks/ind/sic87_sic87dd/sic87dd_key.dta", assert(3) nogenerate

	* Specify dependent variable
	local yvar "dl_cbp_emp"

	* Specify weighting and options
	local aw "[aw = cbp_emp1991]"
	local options "noconstant vce(cluster sic3)"

	label var d_import_usch "Direct Import Exposure"

	if "`k'" == "firstorder" {
		label var d_up_usch "First-Order Upstream Import Exposure"
		label var d_down_usch "First-Order Downstream Import Exposure"
		label var d_omnibus_usch "Combined Direct/Upstream Import Exposure"
	}
	else if "`k'" == "leontief" {
		label var d_up_usch "Full Upstream Import Exposure"
		label var d_down_usch "Full Downstream Import Exposure"
		label var d_omnibus_usch "Combined Direct/Upstream Import Exposure"
	}

	* Demean manufacturing sector controls so that changes in the constant coefficient are interpretable
	foreach var of varlist `sector_controls' {
		foreach span in "1991_1999" "1999_2011" "1999_2007" {
			quietly sum `var' if period == "`span'" & manuf == 1 `aw'
			replace `var' = `var' - r(mean) if period == "`span'" & manuf == 1
			replace `var' = 0 if period == "`span'" & manuf == 0
		}
	}

	tempfile core
	save "`core'.dta", replace

	estimates clear

	/* Regression specs for the period 1991-2011 */

	use "`core'.dta", clear
	keep if period == "1991_1999" | period == "1999_2011"

	/*
		Manufacturing only:
		- Direct + upstream
		- Direct + upstream + downstream
		- Direct + upstream (with controls)
	*/

	eststo mfg1: quietly ivregress 2sls `yvar' t1_manuf t2_manuf (d_import_usch d_up_usch = d_import_otch d_up_otch) `aw' if manuf == 1, `options'
	eststo mfg2: quietly ivregress 2sls `yvar' t1_manuf t2_manuf (d_import_usch d_up_usch d_down_usch = d_import_otch d_up_otch d_down_otch) `aw' if manuf == 1, `options'
	eststo mfg3: quietly ivregress 2sls `yvar' t1_manuf t2_manuf `sector_controls' (d_import_usch d_up_usch = d_import_otch d_up_otch) `aw' if manuf == 1, `options'

	/*
		Non-manufacturing only:
		- Upstream
		- Upstream + downstream
	*/

	eststo nonmfg1: quietly ivregress 2sls `yvar' t1_nonmanuf t2_nonmanuf (d_up_usch = d_up_otch) `aw' if manuf == 0, `options'
	eststo nonmfg2: quietly ivregress 2sls `yvar' t1_nonmanuf t2_nonmanuf (d_up_usch d_down_usch = d_up_otch d_down_otch) `aw' if manuf == 0, `options'

	/*
		Pooling manufacturing and non-manufacturing:
		- Direct + upstream
		- Direct + upstream + downstream
		- Direct + upstream (with controls)
	*/

	eststo pool1: quietly ivregress 2sls `yvar' t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf (d_import_usch d_up_usch = d_import_otch d_up_otch) `aw', `options'
	eststo pool2: quietly ivregress 2sls `yvar' t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf (d_import_usch d_up_usch d_down_usch = d_import_otch d_up_otch d_down_otch) `aw', `options'
	eststo pool3: quietly ivregress 2sls `yvar' t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf `sector_controls' (d_import_usch d_up_usch = d_import_otch d_up_otch) `aw', `options'

	* Compute implied employment effects for our preferred specifications
	estimates restore pool1
	replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * ((_b[d_import_usch] * `pfactor' * d_import_usch) + (_b[d_up_usch] * `pfactor' * d_up_usch))))
	compute_changes

	estimates restore pool3
	replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * ((_b[d_import_usch] * `pfactor' * d_import_usch) + (_b[d_up_usch] * `pfactor' * d_up_usch))))
	compute_changes

	/* Replicate our preferred spec for the period 1991-2007 */
	
	use "`core'.dta", clear
	keep if period == "1991_1999" | period == "1999_2007"
	
	eststo pool1_9107: quietly ivregress 2sls `yvar' t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf (d_import_usch d_up_usch = d_import_otch d_up_otch) `aw', `options'

	* Compute implied employment effects over 1991-2007
	estimates restore pool1_9107
	replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * ((_b[d_import_usch] * `pfactor' * d_import_usch) + (_b[d_up_usch] * `pfactor' * d_up_usch))))
	compute_changes
	
	/* Replicate our preferred spec using an "omnibus" measure that combines direct/upstream import exposure in a single term */
	
	use "`core'.dta", clear
	keep if period == "1991_1999" | period == "1999_2011"

	eststo pool1_omnibus: quietly ivregress 2sls `yvar' t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf (d_omnibus_usch = d_import_otch d_up_otch) `aw', `options'
	
	* Compute implied employment effects for the omnibus specification
	estimates restore pool1_omnibus
	replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * ((_b[d_omnibus_usch] * `pfactor' * d_omnibus_usch))))
	compute_changes

	/* Specify the periods covered */
	
	foreach m in mfg1 mfg2 mfg3 nonmfg1 nonmfg2 pool1 pool2 pool3 pool1_omnibus {
		estimates restore `m'
		estadd local span "1991-2011"
	}

	estimates restore pool1_9107
	estadd local span "1991-2007"
	
	/* Test equality of the direct, upstream, and "omnibus" coefficients (as predicted by the theory) */

	if "`k'" == "firstorder" {
		local filestat "replace"
	}
	else if "`k'" == "leontief" {
		local filestat "append"
	}

	* Test whether the direct and upstream coefficients are equal in our pooled spec without sector controls	
	estimates restore pool1
	log using "`outdir'/auxiliary/io_test.txt", text `filestat'
	di "`k'"
	test d_import_usch = d_up_usch
	log close
	
	* Test whether the direct and upstream coefficients equal the "omnibus" coefficient
	estimates restore pool1_omnibus
	local target = _b[d_omnibus_usch]

	estimates restore pool1
	di "`k'"
	log using "`outdir'/auxiliary/io_test.txt", text append
	test (d_import_usch = `target') (d_up_usch = `target')
	log close
	
	/* Print out the results */
	
	tempfile specs

	#delimit ;
	esttab * using "`specs'.csv",
		nodepvars
		collabels(, none)
		mlabels(, none)
		mgroups("Manufacturing Only" "Non-Manufacturing Only" "Pooled", pattern(1 0 0 1 0 1 0 0 0 0))
		indicate("Mfg/Non-Mfg x Period Dummies = t1_manuf t2_manuf t1_nonmanuf t2_nonmanuf" "1-Digit Mfg Sector Controls = `sector_controls'")
		order(d_import_usch d_up_usch d_down_usch d_omnibus_usch t1_manuf t2_manuf t1_nonmanuf t2_manuf)
		b(%9.2f) se(%9.2f)
		star(* .10 ** .05 *** .01)
		nonotes
		label
		stats(span N tot_pred_d_emp_mfg tot_pred_d_emp_nonmfg tot_pred_d_emp t1_tot_pred_d_emp_mfg t1_tot_pred_d_emp_nonmfg t1_tot_pred_d_emp t2_tot_pred_d_emp_mfg t2_tot_pred_d_emp_nonmfg t2_tot_pred_d_emp, labels("Period" "N" "Pred Emp Change in Mfg, 1991-2011 (or 1991-2007)" "Pred Emp Change in Non-Mfg, 1991-2011 (or 1991-2007)" "Pred Emp Change Overall, 1991-2011 (or 1991-2007)" "Pred Emp Change in Mfg, 1991-1999" "Pred Emp Change in Non-Mfg, 1991-1999" "Pred Emp Change Overall, 1991-1999" "Pred Emp Change in Mfg, 1999-2011 (or 1999-2007)" "Pred Emp Change in Non-Mfg, 1999-2011 (or 1999-2007)" "Pred Emp Change Overall, 1999-2011 (or 1999-2007)") fmt(0))
		replace;
	#delimit cr

	* Save the results
	insheet using "`specs'.csv", comma clear

	if "`k'" == "firstorder" {
		export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab6_Raw)
	}
	else if "`k'" == "leontief" {
		export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetmodify cell(A28) sheet(Tab6_Raw)
	}
}


